OC.L10N.register(
    "files_rightclick",
    {
    "Unselect all" : "Zrušit výběr všeho",
    "Share folder" : "Nasdílet složku",
    "Share file" : "Nasdílet soubor",
    "Select" : "Označit",
    "Copied !" : "Zkopírováno",
    "Right click" : "Kliknutí pravým tlačítkem myši",
    "Right click menu for Nextcloud" : "Nabídka pod pravým tlačítkem myši pro Nextcloud",
    "This app allows users and developers to have a right click menu. Simply use the RightClick object to quickly create context menus. The Files app already shows the actions menu when right clicking on files and folders." : "Tato aplikace umožňuje uživatelům (a vývojářům) mít kontextovou nabídku. Stačí použít objekt RightClick a snadno a rychle tak vytvářet kontextové nabídky. Např. aplikace Soubory zobrazí nabídku akcí při kliknutí pravým tlačítkem na soubory a složky."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
